==> nivo-0.6.0.tgz: package/es/components/charts/treemap/TreeMap.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import { findDOMNode } from 'react-dom';
import _ from 'lodash-es';
import { convertLabel } from '../../../lib/propertiesConverters';
import { treeMapPropTypes, treeMapDefaultProps } from './TreeMapProps';
import TreeMapPlaceholders from './TreeMapPlaceholders';
import { getColorGenerator } from '../../../ColorUtils';

var createNodes = function createNodes(_ref) {
    var borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        enableLabels = _ref.enableLabels,
        _label = _ref.label,
        labelFormat = _ref.labelFormat,
        orientLabels = _ref.orientLabels,
        labelSkipSize = _ref.labelSkipSize,
        labelTextColor = _ref.labelTextColor;

    var label = convertLabel(_label, labelFormat);
    var borderColorFn = getColorGenerator(borderColor);
    var textColorFn = getColorGenerator(labelTextColor);

    return function (nodes) {
        var renderedNodes = [];

        nodes.forEach(function (node) {
            var shouldRenderLabel = enableLabels && node.data.height === 0 && (labelSkipSize === 0 || Math.min(node.style.width, node.style.height) > labelSkipSize);

            var rotate = shouldRenderLabel && orientLabels && node.style.height > node.style.width;

            renderedNodes.push(React.createElement(
                'g',
                {
                    key: node.key,
                    className: 'nivo_treemap_node',
                    transform: 'translate(' + node.style.x + ',' + node.style.y + ')'
                },
                React.createElement('rect', {
                    width: node.style.width,
                    height: node.style.height,
                    fill: node.style.color,
                    stroke: borderColorFn(node.data),
                    strokeWidth: borderWidth
                }),
                shouldRenderLabel && React.createElement(
                    'g',
                    {
                        transform: 'translate(' + node.style.width / 2 + ',' + node.style.height / 2 + ') rotate(' + (rotate ? '-90' : '0') + ')'
                    },
                    React.createElement(
                        'text',
                        {
                            className: 'nivo_treemap_node_label',
                            textAnchor: 'middle',
                            dy: '0.5em',
                            style: {
                                fill: textColorFn(node.data)
                            }
                        },
                        label(node.data.data)
                    )
                )
            ));
        });

        return renderedNodes;
    };
};

var TreeMap = function (_Component) {
    _inherits(TreeMap, _Component);

    function TreeMap() {
        _classCallCheck(this, TreeMap);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    TreeMap.prototype.render = function render() {
        return React.createElement(
            TreeMapPlaceholders,
            _extends({}, this.props, { namespace: 'svg' }),
            createNodes(this.props)
        );
    };

    return TreeMap;
}(Component);

TreeMap.propTypes = _.omit(treeMapPropTypes, ['children', 'namespace']);

TreeMap.defaultProps = _.omit(treeMapDefaultProps, []);

export default TreeMap;

==> nivo-0.7.0.tgz: package/es/components/charts/treemap/TreeMap.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/*
 * This file is part of the nivo project.
 *
 * Copyright 2016-present, Raphaël Benitte.
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

import React, { Component } from 'react';
import { findDOMNode } from 'react-dom';
import _ from 'lodash-es';
import { convertLabel } from '../../../lib/propertiesConverters';
import { treeMapPropTypes, treeMapDefaultProps } from './TreeMapProps';
import TreeMapPlaceholders from './TreeMapPlaceholders';
import { getColorGenerator } from '../../../lib/colorUtils';

var createNodes = function createNodes(_ref) {
    var borderWidth = _ref.borderWidth,
        borderColor = _ref.borderColor,
        enableLabels = _ref.enableLabels,
        _label = _ref.label,
        labelFormat = _ref.labelFormat,
        orientLabels = _ref.orientLabels,
        labelSkipSize = _ref.labelSkipSize,
        labelTextColor = _ref.labelTextColor;

    var label = convertLabel(_label, labelFormat);
    var borderColorFn = getColorGenerator(borderColor);
    var textColorFn = getColorGenerator(labelTextColor);

    return function (nodes) {
        var renderedNodes = [];

        nodes.forEach(function (node) {
            var shouldRenderLabel = enableLabels && node.data.height === 0 && (labelSkipSize === 0 || Math.min(node.style.width, node.style.height) > labelSkipSize);

            var rotate = shouldRenderLabel && orientLabels && node.style.height > node.style.width;

            renderedNodes.push(React.createElement(
                'g',
                {
                    key: node.key,
                    className: 'nivo_treemap_node',
                    transform: 'translate(' + node.style.x + ',' + node.style.y + ')'
                },
                React.createElement('rect', {
                    width: node.style.width,
                    height: node.style.height,
                    fill: node.style.color,
                    stroke: borderColorFn(node.data),
                    strokeWidth: borderWidth
                }),
                shouldRenderLabel && React.createElement(
                    'g',
                    {
                        transform: 'translate(' + node.style.width / 2 + ',' + node.style.height / 2 + ') rotate(' + (rotate ? '-90' : '0') + ')'
                    },
                    React.createElement(
                        'text',
                        {
                            className: 'nivo_treemap_node_label',
                            textAnchor: 'middle',
                            dy: '0.5em',
                            style: {
                                fill: textColorFn(node.data)
                            }
                        },
                        label(node.data.data)
                    )
                )
            ));
        });

        return renderedNodes;
    };
};

var TreeMap = function (_Component) {
    _inherits(TreeMap, _Component);

    function TreeMap() {
        _classCallCheck(this, TreeMap);

        return _possibleConstructorReturn(this, _Component.apply(this, arguments));
    }

    TreeMap.prototype.render = function render() {
        return React.createElement(
            TreeMapPlaceholders,
            _extends({}, this.props, { namespace: 'svg' }),
            createNodes(this.props)
        );
    };

    return TreeMap;
}(Component);

TreeMap.propTypes = _.omit(treeMapPropTypes, ['children', 'namespace']);

TreeMap.defaultProps = _.omit(treeMapDefaultProps, []);

export default TreeMap;
